@@ -111,7 +111,8 @@ class BotGoogleDrivePlugin:
         """
         self.drive_service.files().delete(fileId=file_id).execute()
 
-    def create_folder(self, folder_name: str) -> str:
+    def create_folder(self, folder_name: str,
+                      parent_folder_id: Optional[str] = None) -> str:
         """
         Create a folder on Google Drive.
 
@@ -125,12 +126,17 @@ class BotGoogleDrivePlugin:
             'name': folder_name,
             'mimeType': 'application/vnd.google-apps.folder'
         }
+        if parent_folder_id:
+            file_metadata['parents'] = [parent_folder_id]
+
         file = self.drive_service.files().create(body=file_metadata,
                                                  fields='id').execute()
+
         return file.get('id')
 
     def upload_file(self, file_path: str, file_name: str,
-                    parent_folder_id: Optional[str] = None, mime_type: Optional[str] = None):
+                    parent_folder_id: Optional[str] = None,
+                    mime_type: Optional[str] = None) -> str or None:
         """
         Upload a file on Google Drive.
 
@@ -140,6 +146,9 @@ class BotGoogleDrivePlugin:
             parent_folder_id: Id of the folder that will receive the file,
                               otherwise it will be uploaded to the main folder.
             mime_type: The MIME type corresponding to the file if necessary.
+
+        Returns:
+            The uploaded file id or None.
         """
         file_metadata = {'name': file_name}
 
